<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="sr" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../ReText/config.py" line="80"/>
        <source>Using configuration file at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Behavior</source>
        <translation>Понашање</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically save documents</source>
        <translation>Аутоматски сачувај документе</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically open last documents on startup</source>
        <translation>На почетку, аутоматски отвори последње документе</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Number of recent documents</source>
        <translation>Број скорашњих докумената</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Restore window geometry</source>
        <translation>Упамти геометрију прозора</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Default preview state</source>
        <translation>Подразумевано стање прегледа</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Open external links in ReText window</source>
        <translation>Отварај спољне везе у РеТекст прозору</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Маркдаун проширења синтаксе (одвојено запетом)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>Укључи синхронизовано клизање за Маркдаун</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="169"/>
        <source>Editor</source>
        <translation>Уређивач</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Highlight current line</source>
        <translation>Истакни тренутну линију</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show line numbers</source>
        <translation>Прикажи бројеве линија</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Line numbers are relative to current line</source>
        <translation>Бројеви линија су релативни у односу на тренутну</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tab key inserts spaces</source>
        <translation>Таб убацује размаке</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tabulation width</source>
        <translation>Ширина табулације</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Draw vertical line at column</source>
        <translation>Исцртај вертикалну линију на колони</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable soft wrap</source>
        <translation>Укључи меки прелом</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show document stats</source>
        <translation>Прикажи статистику документа</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Interface</source>
        <translation>Сучеље</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide toolbar</source>
        <translation>Сакриј траку алатки</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Icon theme name</source>
        <translation>Назив теме икона</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Stylesheet file</source>
        <translation>Фајл распореда</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide tabs bar when there is only one tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show full path in window title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="151"/>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="170"/>
        <source>Live preview</source>
        <translation>Тренутни преглед</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="171"/>
        <source>Normal preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="35"/>
        <source>(none)</source>
        <translation>(ништа)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="42"/>
        <source>Select file to open</source>
        <translation>Изаберите фајл</translation>
    </message>
</context>
<context>
    <name>InsertTableDialog</name>
    <message>
        <location filename="../ReText/tabledialog.py" line="27"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="36"/>
        <source>Number of rows</source>
        <translation>Број редова</translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="37"/>
        <source>Number of columns</source>
        <translation>Број колона</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../ReText/dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Унесите ознаку локалитета (нпр. sr_RS)</translation>
    </message>
    <message>
        <location filename="../ReText/dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Постави као подразумевано</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="61"/>
        <source>No write since last change (add ! to override)</source>
        <translation>Нема уписа од последње измене (додајте ! да прегазите)</translation>
    </message>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="118"/>
        <source>Information</source>
        <translation>Подаци</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="../ReText/editor.py" line="212"/>
        <source>Add to dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Save image</source>
        <translation>Сачувај слику</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Images (*.png *.jpg)</source>
        <translation>Слике (*.png *.jpg)</translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="../ReText/tab.py" line="184"/>
        <source>New document</source>
        <translation>Нови документ</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="189"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Не могу да рашчланим садржај фајла. Проверите имате ли инсталиран &lt;a href=&quot;%s&quot;&gt;неопходaн модул&lt;/a&gt;!</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>Create missing file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>The file &apos;%s&apos; does not exist.

Do you want to create it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>File could not be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>Could not create file &apos;%s&apos;: %s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="../ReText/window.py" line="82"/>
        <source>File toolbar</source>
        <translation>Алатна трака фајла</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="84"/>
        <source>Edit toolbar</source>
        <translation>Алатна трака уређивања</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="86"/>
        <source>Search toolbar</source>
        <translation>Алатна трака тражења</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="90"/>
        <source>New</source>
        <translation>Ново</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="93"/>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="96"/>
        <source>Set encoding</source>
        <translation>Постави кодирање</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1190"/>
        <source>Reload</source>
        <translation>Учитај поново</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="102"/>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="106"/>
        <source>Save as</source>
        <translation>Сачувај као</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="108"/>
        <source>Next tab</source>
        <translation>Следећи језичак</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="110"/>
        <source>Previous tab</source>
        <translation>Претходни језичак</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="112"/>
        <source>Close tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="114"/>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="117"/>
        <source>Print preview</source>
        <translation>Приказ штампе</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="119"/>
        <source>View HTML code</source>
        <translation>Погледај ХТМЛ код</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="120"/>
        <source>Change editor font</source>
        <translation>Измени фонт уређивача</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="122"/>
        <source>Change preview font</source>
        <translation>Измени фонт прегледа</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="124"/>
        <source>Find text</source>
        <translation>Нађи текст</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Go to line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="129"/>
        <source>Preview</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="139"/>
        <source>Live preview</source>
        <translation>Тренутни преглед</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="144"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="146"/>
        <source>Table editing mode</source>
        <translation>Режим уређивања табеле</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="152"/>
        <source>FakeVim mode</source>
        <translation>Лажни Вим режим</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="157"/>
        <source>Fullscreen mode</source>
        <translation>Режим пуног екрана</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="630"/>
        <source>Preferences</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="168"/>
        <source>Quit</source>
        <translation>Напусти</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="171"/>
        <source>Undo</source>
        <translation>Поништи</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="173"/>
        <source>Redo</source>
        <translation>Понови</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="175"/>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="177"/>
        <source>Cut</source>
        <translation>Исеци</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="179"/>
        <source>Paste</source>
        <translation>Налепи</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="181"/>
        <source>Paste image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="183"/>
        <source>Move line up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="185"/>
        <source>Move line down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="195"/>
        <source>Enable</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="196"/>
        <source>Set locale</source>
        <translation>Постави локалитет</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="197"/>
        <source>Use WebKit renderer</source>
        <translation>Користи ВебКит исцртавач</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="202"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation>Користи ВебМотор (Хромијум) исцртавач</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="207"/>
        <source>Show directory</source>
        <translation>Прикажи директоријум</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="208"/>
        <source>Next</source>
        <translation>Следеће</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="210"/>
        <source>Previous</source>
        <translation>Претходно</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="212"/>
        <source>Replace</source>
        <translation>Замени</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="214"/>
        <source>Replace all</source>
        <translation>Замени све</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="218"/>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="222"/>
        <source>Get help online</source>
        <translation>Потражите помоћ на интернету</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="223"/>
        <source>About ReText</source>
        <translation>О РеТексту</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="226"/>
        <source>About Qt</source>
        <translation>О КуТ-у</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="241"/>
        <source>Bold</source>
        <translation>Подебљано</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="243"/>
        <source>Italic</source>
        <translation>Курзивно</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="245"/>
        <source>Underline</source>
        <translation>Подвучено</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="318"/>
        <source>Formatting</source>
        <translation>Форматирање</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="258"/>
        <source>Symbols</source>
        <translation>Симболи</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="263"/>
        <source>File</source>
        <translation>Фајл</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="264"/>
        <source>Edit</source>
        <translation>Уређивање</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="265"/>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="268"/>
        <source>Open recent</source>
        <translation>Отвори недавне</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="281"/>
        <source>Export</source>
        <translation>Извези</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="306"/>
        <source>Spell check</source>
        <translation>Провера правописа</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="315"/>
        <source>Default markup</source>
        <translation>Подразумевана маркација</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="360"/>
        <source>Search</source>
        <translation>Тражи</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="363"/>
        <source>Replace with</source>
        <translation>Замени са</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="365"/>
        <source>Case sensitively</source>
        <translation>Осетљив на вел. слова</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="526"/>
        <source>New document</source>
        <translation>Нови документ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Type the line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="714"/>
        <source>Please, save the file somewhere.</source>
        <translation>Сачувајте фајл негде.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="830"/>
        <source>Select one or several files to open</source>
        <translation>Изаберите један или више фајлова за отварање</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Supported files</source>
        <translation>Подржани фајлови</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>All files (*)</source>
        <translation>Сви фајлови (*)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="869"/>
        <source>Select file encoding from the list:</source>
        <translation>Са листе изаберите кодирање фајла:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="892"/>
        <source>Plain text (*.txt)</source>
        <translation>Обичан текст (*.txt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="895"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s фајлови</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>Save file</source>
        <translation>Сачувај фајл</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="915"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation>Не могу да сачувам јер је отворен у другом језичку!</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="938"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Не могу да сачувам јер је фајл само за читање!</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>Export document to ODT</source>
        <translation>Извези документ у ОДТ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>ОпенДокумент текстуални фајл (*.odt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>ХТМЛ фајлови (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="993"/>
        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>Export document to PDF</source>
        <translation>Извези документ у ПДФ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>PDF files (*.pdf)</source>
        <translation>ПДФ фајлови (*.pdf)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1046"/>
        <source>Print document</source>
        <translation>Штампај документ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1069"/>
        <source>Export document</source>
        <translation>Извези документ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1090"/>
        <source>Failed to execute the command:</source>
        <translation>Неуспело извршење команде:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1131"/>
        <source>Alt text</source>
        <translation>Алт текст</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>URL</source>
        <translation>УРЛ</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>Link text</source>
        <translation>Текст везе</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Овај фајл је обрисала друга апликације.
Сачувајте га пре него што изађете.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1181"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Овај документ је изменила друга апликација.
Желите ли да га поново учитате? (ово ће поништити све ваше измене)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1186"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Ако изаберете да не учитате поново, аутоматско чување биће искључено за ову сесију да би се спречио губитак података.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1210"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Документ је измењен.
Желите ли да сачувате ваше измене?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1238"/>
        <source>HTML code</source>
        <translation>ХТМЛ код</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>РеТекст %s (користећи PyMarkups %s)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Једноставан али моћан уређивач за Маркдаун и реструктуирани текст</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Аутор: Дмитриј Шачнев (Dmitry Shachnev), 2011</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Website</source>
        <translation>Веб сајт</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Markdown syntax</source>
        <translation>Маркдаун синтакса</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>reStructuredText syntax</source>
        <translation>Синтакса реструктуираног текста</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="149"/>
        <source>Insert images by file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Select one or several images to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextInfoArea</name>
    <message>
        <location filename="../ReText/editor.py" line="582"/>
        <source>%d w | %d a | %d c</source>
        <comment>count of words, alphanumeric characters, all characters</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../ReText/__main__.py" line="77"/>
        <source>Open the files in preview mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="79"/>
        <source>Create a new window even if there is an existing one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="83"/>
        <source>List of files to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
